BAUDRATE_FW_DEFINE = {
    'NRF_UARTE_BAUDRATE_921600': 921600,
    'NRF_UARTE_BAUDRATE_460800': 460800,
    'NRF_UARTE_BAUDRATE_250000': 250000,
    'NRF_UARTE_BAUDRATE_230400': 230400,
    'NRF_UARTE_BAUDRATE_115200': 115200,
    'NRF_UARTE_BAUDRATE_76800': 76800,
    'NRF_UARTE_BAUDRATE_57600': 57600,
    'NRF_UARTE_BAUDRATE_56000': 56000,
    'NRF_UARTE_BAUDRATE_38400': 38400,
    'NRF_UARTE_BAUDRATE_28800': 28800,
    'NRF_UARTE_BAUDRATE_19200': 19200,
    'NRF_UARTE_BAUDRATE_14400': 14400,
    'NRF_UARTE_BAUDRATE_9600': 9600,
    'NRF_UARTE_BAUDRATE_4800': 4800,
    'NRF_UARTE_BAUDRATE_2400': 2400,
    'NRF_UARTE_BAUDRATE_1200': 1200,
}

DEFAULT_BAUDRATE_VALUE = 921600